"""added ohlcv

Revision ID: 787b01c0212f
Revises:
Create Date: 2024-05-27 01:37:06.799955

"""

import sqlalchemy as sa
from alembic import op
from sqlalchemy.dialects import postgresql

# revision identifiers, used by Alembic.
revision = "787b01c0212f"
down_revision = None
branch_labels = None
depends_on = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    exchange_enum = postgresql.ENUM(name="exchange", schema="public", create_type=False)
    op.create_table(
        "ohlcv",
        sa.Column("open", sa.Float(), nullable=False),
        sa.Column("high", sa.Float(), nullable=False),
        sa.Column("low", sa.Float(), nullable=False),
        sa.Column("close", sa.Float(), nullable=False),
        sa.Column("volume", sa.Float(), nullable=False),
        sa.Column("exchange", exchange_enum, nullable=False),
        sa.Column("symbol", sa.String(), nullable=False),
        sa.Column("timestamp", sa.BIGINT(), nullable=False),
        sa.Column("datetime", sa.DateTime(), nullable=False),
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("created_at", sa.TIMESTAMP(), nullable=False),
        sa.Column("updated_at", sa.TIMESTAMP(), nullable=False),
        sa.PrimaryKeyConstraint("id"),
        schema="crypto",
    )
    op.create_index(
        "ix_ohlcv_created_at", "ohlcv", ["created_at"], unique=False, schema="crypto"
    )
    op.create_index(
        "ix_ohlcv_exchange_symbol_timestamp",
        "ohlcv",
        ["exchange", "symbol", "timestamp"],
        unique=True,
        schema="crypto",
    )
    op.create_index(
        "ix_ohlcv_timestamp", "ohlcv", ["timestamp"], unique=False, schema="crypto"
    )
    op.create_index(
        "ix_ohlcv_time_of_minute",
        "ohlcv",
        [sa.text("EXTRACT(minute from datetime)")],
        unique=False,
        schema="crypto",
    )
    op.create_index(
        "ix_ohlcv_updated_at", "ohlcv", ["updated_at"], unique=False, schema="crypto"
    )
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index("ix_ohlcv_updated_at", table_name="ohlcv", schema="crypto")
    op.drop_index("ix_ohlcv_time_of_minute", table_name="ohlcv", schema="crypto")
    op.drop_index(
        "ix_ohlcv_timestamp_exchange_symbol", table_name="ohlcv", schema="crypto"
    )
    op.drop_index("ix_ohlcv_created_at", table_name="ohlcv", schema="crypto")
    op.drop_table("ohlcv", schema="crypto")
    # ### end Alembic commands ###
